Learn R Programming

ecd (version 0.6.4)

ecd.max_kurtosis: Utility to calculate where the maximum kurtosis is on the positive j=0 line

Description

This utility calculates the kurtosis for alpha from 2.85 to 3.00. Then the location and value of maximum kurtosis is presented.

Usage

ecd.max_kurtosis(jinv = 0)

Arguments

jinv
specify 0 (default) or 1728.

Value

numeric vector, in which the first element is alpha, and the second element is the maximum kurtosis.

Examples

Run this code
## Not run: 
#     k <- ecd.max_kurtosis()
#     alpha <- k[1]
#     kurtosis <- k[2]
# ## End(Not run)

Run the code above in your browser using DataLab