ecdattr objects in polar coordinateThe list is created by the Cartesian product between R and theta.
This contains the data points of a circular area defined by R,theta.
If cusp is 1, data points are on the critical line specified by R.
ecdattr.pairs_polar(R, theta, cusp = 0, use.mpfr = FALSE)numeric vectors
numeric, representing type of cusp. Only 0 (default) and 1 are allowed.
logical, whether to use mpfr for ecd object, default is FALSE.
a list of basic ecdattr objects.