Learn R Programming

ecd (version 0.6.4)

ecld.ivol_ogf_star: Calculate implied volatility using star OGF and small sigma formula

Description

Calculate implied volatility using star OGF and small sigma formula. Only the postive ki and Lc is supported. SGED is not supported yet.

Usage

ecld.ivol_ogf_star(object, ki, epsilon = 0, otype = "c", order.local = Inf, order.global = Inf, ignore.mu = FALSE)

Arguments

object
an object of ecld class
ki
a numeric vector of log-strike
epsilon
numeric, small asymptotic premium added to local regime
otype
option type
order.local
numeric, order of the hypergeometric series to be computed for local regime. Default is Inf, use the incomplete gamma. When it is NaN, L* value is suppressed.
order.global
numeric, order of the hypergeometric series to be computed for global regime. Default is Inf, use the incomplete gamma.
ignore.mu
logical, ignore exp(mu) on both sides, default is FALSE.

Value

The state price of option in star OGF terms. For ecld.ivol_ogf_star, it is $\sigma_1$.

Examples

Run this code
ld <- ecld(sigma=0.001)
ecld.ivol_ogf_star(ld, 0)

Run the code above in your browser using DataLab