Learn R Programming

ecd (version 0.6.4)

ecop.from_symbol_conf: Constructor of ecop class by read conf for option sample data

Description

Read conf for option sample data and fitting parameters

Usage

ecop.from_symbol_conf(key, conf_file = "conf/ecop-fit-conf.yml", conf_data = NULL)
ecop.read_symbol_conf(key, conf_file = "conf/ecop-fit-conf.yml")
ecop.build_opt(ecop, df, otype)

Arguments

key
character. The top-level key in conf
conf_file
file name fof symbol config, default to conf/ecld-fit-conf.yml
conf_data
optionally feed config through a list. If this is not null, this takes priority and conf_file will be ignored.
ecop
an ecop object with conf
df
dataframe of a single closing date and time to maturity
otype
option type

Value

the ecop object

Examples

Run this code
## Not run: 
#     conf <- ecop.read_symbol_conf("spx2_1d")
#     op <- ecop.from_symbol_conf("spx2_1d")
# ## End(Not run)

Run the code above in your browser using DataLab