Learn R Programming

ecd (version 0.6.4)

moment.ecd: Compute the moment of ecd via integration

Description

Compute the moment of ecd via integration between -Inf and Inf. The asymp.lower and asymp.upper parameters are used for asymptotic statistics, to study the effect of finite observations.

Usage

"moment"(object, order, center = FALSE, asymp.lower = -Inf, asymp.upper = Inf, verbose = FALSE)
moment(object, order, center = FALSE, asymp.lower = -Inf, asymp.upper = Inf, verbose = FALSE)
"moment"(object, order, center = FALSE, asymp.lower = -Inf, asymp.upper = Inf, verbose = FALSE)

Arguments

object
an object of ecd class
order
numeric. Order of the moment to be computed
center
logical. If set to TRUE, calculate central moments. Default: FALSE.
asymp.lower
numeric, lower bound for asymptotic statistics, default: -Inf.
asymp.upper
numeric, upper bound for asymptotic statistics, default: Inf.
verbose
logical, display timing information, for debugging purpose.

Value

Numeric. The moment.

Examples

Run this code
d <- ecd()
moment(d, 2)

Run the code above in your browser using DataLab