Learn R Programming

ecd (version 0.6.4)

ecd.fit_ts_conf: Timeseries fitting utility

Description

Fitting timeseries with provided conf as starting set of parameters.

Usage

ecd.fit_ts_conf(ts, conf, iter = 1000, FIT = FALSE, EPS = FALSE, eps_file = NULL, qa.fit = FALSE)

Arguments

ts
An xts object from either ecd.data or ecd.df2ts.
conf
A nested list object, the configuration.
iter
A length-one numeric. Number of maximum iterations. Default: 1000.
FIT
Logical, indicating whether to call linear regression, default = FALSE
EPS
Logical, indicating whether to save the plot to EPS, default = FALSE
eps_file
File name for eps output
qa.fit
Logical, qa the standardfit_fn once.

Value

Final ecd object

Examples

Run this code
## Not run: 
# d <- ecd.fit_ts_conf(ts, conf)
# ## End(Not run)

Run the code above in your browser using DataLab