Arguments
ts
An xts object from either ecd.data or ecd.df2ts.
conf
A nested list object, the configuration.
iter
A length-one numeric. Number of maximum iterations. Default: 1000.
FIT
Logical, indicating whether to call linear regression, default = FALSE
EPS
Logical, indicating whether to save the plot to EPS, default = FALSE
eps_file
File name for eps output
qa.fit
Logical, qa the standardfit_fn once.