ecdattr objects in polar coordinateR and theta.
This contains the data points of a circular area defined by R,theta.
If cusp is 1, data points are on the critical line specified by R.
ecdattr.pairs_polar(R, theta, cusp = 0, use.mpfr = FALSE)FALSE.ecdattr objects.